@@ -367,6 +367,13 @@ gb_widget_write_standard_source (GtkWidget * widget,
 
   if (wdata->tooltip)
     {
+      gboolean translatable, context;
+      gchar *comments;
+
+      glade_util_get_translation_properties (widget, GbTooltip, &translatable,
+					     &comments, &context);
+      source_add_translator_comments (data, translatable, comments);
+
       data->need_tooltips = TRUE;
 
       /* GtkToolItem subclasses use a special function, since otherwise they
@@ -376,14 +383,14 @@ gb_widget_write_standard_source (GtkWidget * widget,
 	  source_add (data,
 		      "  gtk_tool_item_set_tooltip (GTK_TOOL_ITEM (%s), tooltips, %s, NULL);\n",
 		      data->wname,
-		      source_make_string (wdata->tooltip, data->use_gettext));
+		      source_make_string_full (wdata->tooltip, data->use_gettext && translatable, context));
 	}
       else
 	{
 	  source_add (data,
 		      "  gtk_tooltips_set_tip (tooltips, %s, %s, NULL);\n",
 		      data->wname,
-		      source_make_string (wdata->tooltip, data->use_gettext));
+		      source_make_string_full (wdata->tooltip, data->use_gettext && translatable, context));
 	}
     }
 
@@ -966,6 +973,7 @@ init_signal_hash (void)
      */
     { "GtkAccelGroup::accel_activate", "accelgroup,object,key,modifier" },
     { "GtkAccelGroup::accel_changed", "accelgroup,key,modifier,closure" },
+    { "GtkCellRenderer::editing_started", "cellrenderer,editable,path" },
     { "GtkCellRendererText::edited", "cellrenderertext,path,new_text" },
     { "GtkCellRendererToggle::toggled", "cellrenderertoggle,path" },
     { "GtkCList::click_column", "clist,column" },
@@ -990,6 +998,9 @@ init_signal_hash (void)
     { "GtkEntry::insert_at_cursor", "entry,string" },
     { "GtkEntry::move_cursor", "entry,step,count,extend_selection" },
     { "GtkEntry::populate_popup", "entry,menu" },
+    { "GtkIconView::item_activated", "iconview,path" },
+    { "GtkIconView::move_cursor", "iconview,step,count" },
+    { "GtkIconView::set_scroll_adjustments", "iconview,hadjustment,vadjustment" },
     { "GtkInputDialog::disable_device", "inputdialog,device" },
     { "GtkInputDialog::enable_device", "inputdialog,device" },
     { "GtkIMContext::commit", "imcontext,string" },
@@ -1023,6 +1034,7 @@ init_signal_hash (void)
     { "GtkPaned::cycle_handle_focus", "paned,reverse" },
     { "GtkPaned::move_handle", "paned,scroll" },
     { "GtkRange::adjust_bounds", "range,value" },
+    { "GtkRange::change_value", "range,scroll,value" },
     { "GtkRange::move_slider", "range,scroll" },
     { "GtkScale::format_value", "scale,value" },
     { "GtkScrolledWindow::move_focus_out", "scrolledwindow,direction" },
@@ -1201,7 +1213,7 @@ gb_widget_write_accelerators_source (GtkWidget * widget,
       data->need_accel_group = TRUE;
       source_add (data,
 		  "  gtk_widget_add_accelerator (%s, \"%s\", accel_group,\n"
-		  "                              GDK_%s, %s,\n"
+		  "                              GDK_%s, (GdkModifierType) %s,\n"
 		  "                              GTK_ACCEL_VISIBLE);\n",
 		  data->wname, accel->signal, accel->key,
 		  glade_util_create_modifiers_string (accel->modifiers));
